@@ -1,7 +1,7 @@
 /*
  * window-tracker-window: A window tracked by window tracker.
  * 
- * Copyright 2012-2016 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2021 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -449,6 +449,26 @@ XfdashboardWindowTrackerWindowState xfdashboard_window_tracker_window_get_state(
 	return(0);
 }
 
+/* Set state of window */
+void xfdashboard_window_tracker_window_set_state(XfdashboardWindowTrackerWindow *self, XfdashboardWindowTrackerWindowState inState)
+{
+	XfdashboardWindowTrackerWindowInterface		*iface;
+
+	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW(self));
+
+	iface=XFDASHBOARD_WINDOW_TRACKER_WINDOW_GET_IFACE(self);
+
+	/* Call virtual function */
+	if(iface->set_state)
+	{
+		return(iface->set_state(self, inState));
+	}
+
+	/* If we get here the virtual function was not overridden */
+	XFDASHBOARD_WINDOWS_TRACKER_WINDOW_WARN_NOT_IMPLEMENTED(self, "set_state");
+	return;
+}
+
 /* Get possible actions for requested window */
 XfdashboardWindowTrackerWindowAction xfdashboard_window_tracker_window_get_actions(XfdashboardWindowTrackerWindow *self)
 {
