@@ -72,9 +72,9 @@ static GParamSpec* XfdashboardHotCornerSettingsProperties[PROP_LAST]={ 0, };
 
 GType xfdashboard_hot_corner_settings_activation_corner_get_type(void)
 {
-	static volatile gsize	g_define_type_id__volatile=0;
+	static gsize	static_g_define_type_id=0;
 
-	if(g_once_init_enter(&g_define_type_id__volatile))
+	if(g_once_init_enter(&static_g_define_type_id))
 	{
 		static const GEnumValue values[]=
 		{
@@ -86,10 +86,10 @@ GType xfdashboard_hot_corner_settings_activation_corner_get_type(void)
 		};
 
 		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardHotCornerSettingsActivationCorner"), values);
-		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+		g_once_init_leave(&static_g_define_type_id, g_define_type_id);
 	}
 
-	return(g_define_type_id__volatile);
+	return(static_g_define_type_id);
 }
 
 
